@@ -180,7 +180,7 @@ class ApiBase:
                 exception_msg = self.decode_support_id(api_response['result']['errormessage'])
 
                 for error in exception_msg['error']:
-                    if 'You do not have permission for API' in error['description2']:
+                    if error['description2'] and 'You do not have permission for API' in error['description2']:
                         raise InvalidTokenError('The user has insufficient privilege', exception_msg)
 
                 raise WrongParamsError('Error during {0}'.format(api_response['result']['function']), exception_msg)
