@@ -48,6 +48,7 @@ class SageIntacctSDK:
         self.checking_accounts = CheckingAccounts()
         self.savings_accounts = SavingsAccounts()
         self.tasks = Tasks()
+        self.expense_payment_types = ExpensePaymentTypes()
 
         self.update_sender_id()
         self.update_sender_password()
@@ -78,6 +79,7 @@ class SageIntacctSDK:
         self.checking_accounts.set_sender_id(self.__sender_id)
         self.savings_accounts.set_sender_id(self.__sender_id)
         self.tasks.set_sender_id(self.__sender_id)
+        self.expense_payment_types.set_sender_id(self.__sender_id)
 
     def update_sender_password(self):
         """
@@ -104,6 +106,7 @@ class SageIntacctSDK:
         self.checking_accounts.set_sender_password(self.__sender_password)
         self.savings_accounts.set_sender_password(self.__sender_password)
         self.tasks.set_sender_password(self.__sender_password)
+        self.expense_payment_types.set_sender_password(self.__sender_password)
 
     def update_session_id(self):
         """
@@ -131,3 +134,4 @@ class SageIntacctSDK:
         self.checking_accounts.set_session_id(self.__session_id)
         self.savings_accounts.set_session_id(self.__session_id)
         self.tasks.set_session_id(self.__session_id)
+        self.expense_payment_types.set_session_id(self.__session_id)
